@@ -8,6 +8,7 @@ mod common_args;
 mod r#enum;
 mod error;
 mod multipart;
+mod oauth_scopes;
 mod object;
 mod request;
 mod response;
@@ -36,7 +37,7 @@ pub fn derive_enum(input: TokenStream) -> TokenStream {
     }
 }
 
-#[proc_macro_derive(Response, attributes(oai))]
+#[proc_macro_derive(ApiResponse, attributes(oai))]
 pub fn derive_response(input: TokenStream) -> TokenStream {
     let args = parse_macro_input!(input as DeriveInput);
     match response::generate(args) {
@@ -45,7 +46,7 @@ pub fn derive_response(input: TokenStream) -> TokenStream {
     }
 }
 
-#[proc_macro_derive(Request, attributes(oai))]
+#[proc_macro_derive(ApiRequest, attributes(oai))]
 pub fn derive_request(input: TokenStream) -> TokenStream {
     let args = parse_macro_input!(input as DeriveInput);
     match request::generate(args) {
@@ -83,6 +84,15 @@ pub fn derive_tags(input: TokenStream) -> TokenStream {
     }
 }
 
+#[proc_macro_derive(OAuthScopes, attributes(oai))]
+pub fn derive_oauth_scopes(input: TokenStream) -> TokenStream {
+    let args = parse_macro_input!(input as DeriveInput);
+    match oauth_scopes::generate(args) {
+        Ok(stream) => stream.into(),
+        Err(err) => err.write_errors().into(),
+    }
+}
+
 #[proc_macro_derive(SecurityScheme, attributes(oai))]
 pub fn derive_security_scheme(input: TokenStream) -> TokenStream {
     let args = parse_macro_input!(input as DeriveInput);
